# coding: utf-8

"""
    Mentortools Public API

    Mentortools public API service

    The version of the OpenAPI document: 1.8.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import json
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class FileType(str, Enum):
    """
    An enumeration.
    """

    """
    allowed enum values
    """
    IMAGE = 'image'
    VIDEO = 'video'
    AUDIO = 'audio'
    DOCUMENT = 'document'
    ARCHIVE = 'archive'
    UNDEFINED = 'undefined'

    @classmethod
    def from_json(cls, json_str: str) -> FileType:
        """Create an instance of FileType from a JSON string"""
        return FileType(json.loads(json_str))


